# tspex

tspex is a Python package for calculating tissue-specificity metrics from gene expression data.

tspex features include:
  - An easy-to-use object-oriented interface.
  - Twelve different tissue-specificity metrics.
  - A plotting function.
  - Support for Jupyter notebooks.

## Installation

```
# Using pip
$ pip install tspex

# using conda
$ conda install -c bioconda tspex
```
